@@ -17,14 +17,14 @@ def get_env_by_file_exist(file_path: str) -> Literal['prod', 'dev']:
         return 'dev'
 
 
-def get_env_by_os_environment() -> Literal['dev', 'prod']:
+def get_env_by_os_environment(check_key: str='ENV') -> Literal['dev', 'prod']:
     '''
     根据环境变量获取环境
 
     Returns:
         Literal['dev', 'prod']: 环境，dev 表示开发环境，prod 表示生产环境
     '''
-    if os.getenv('ENV') == 'dev':
+    if os.getenv(check_key) == 'dev':
         return 'dev'
     else:
         return 'prod'
\ No newline at end of file
